@@ -112,11 +112,12 @@ class App:
         self.appid = appid
 
         # request the data
-        json = requests.get(self.api_url + appid).json()
+        res = requests.get(self.api_url + appid)
 
-        # if game exists
-        if json[appid]['success']:
-            self.data = json[appid]['data']
+        if res.status_code == requests.codes.ok:
+            json = res.json()
+            if json[appid]['success']:
+                self.data = json[appid]['data']
             return self.data
         else:
             return None
